@@ -15,13 +15,20 @@ I<documentation volunteers needed>
 
 requires qw(quote_chars name_sep);
 
+has escape_char => (
+  is      => 'ro',
+  lazy    => 1,
+  clearer => 1,
+  default => sub { $_[0]->quote_chars->[-1] },
+);
+
 sub quote {
   my ($self, $label) = @_;
 
   return '' unless defined $label;
   return $$label if ref($label) eq 'SCALAR';
 
-  my @quote_chars = @{$self->quote_chars};
+  my @quote_chars = @{ $self->quote_chars };
   return $label unless scalar @quote_chars;
 
   my ($l, $r);
@@ -34,8 +41,18 @@ sub quote {
   }
 
   my $sep = $self->name_sep || '';
+  my $esc = $self->escape_char;
+
   # parts containing * are naturally unquoted
-  join $sep, map "$l$_$r", ( $sep ? split (/\Q$sep\E/, $label ) : $label )
+  join $sep, map { (my $n = $_) =~ s/\Q$r/$esc$r/g; "$l$n$r" } ($sep ? split(/\Q$sep\E/, $label) : $label);
+}
+
+sub quote_string {
+  my ($self, $string) = @_;
+
+  return $string unless defined $string;
+  $string =~ s/'/''/g;
+  return qq{'$string'};
 }
 
 1;
