@@ -23,32 +23,33 @@ use Data::Dumper;
 use SQL::Translator::Schema::Constants;
 use SQL::Translator::Parser::MySQL;
 
-our ( $DEBUG, @EXPORT_OK );
-our $VERSION = '1.64';
-$DEBUG   = 0 unless defined $DEBUG;
+our ($DEBUG, @EXPORT_OK);
+our $VERSION = '1.65';
+$DEBUG = 0 unless defined $DEBUG;
 
 sub parse {
-    my ( $tr, $dbh ) = @_;
-    my $schema       = $tr->schema;
-    my @table_names  = @{ $dbh->selectcol_arrayref('show tables') };
-    my @skip_tables  = defined $tr->parser_args->{skip}
-                       ? split(/,/, $tr->parser_args->{skip})
-                       : ();
+  my ($tr, $dbh) = @_;
+  my $schema      = $tr->schema;
+  my @table_names = @{ $dbh->selectcol_arrayref('show tables') };
+  my @skip_tables
+      = defined $tr->parser_args->{skip}
+      ? split(/,/, $tr->parser_args->{skip})
+      : ();
 
-    $dbh->{'FetchHashKeyName'} = 'NAME_lc';
+  $dbh->{'FetchHashKeyName'} = 'NAME_lc';
 
-    my $create = q{};
-    for my $table_name ( @table_names ) {
-        next if (grep /^$table_name$/, @skip_tables);
-        my $sth = $dbh->prepare("show create table " . $dbh->quote_identifier($table_name));
-        $sth->execute;
-        my $table = $sth->fetchrow_hashref;
-        $create .= ($table->{'create table'} || $table->{'create view'}) . ";\n\n";
-    }
+  my $create = q{};
+  for my $table_name (@table_names) {
+    next if (grep /^$table_name$/, @skip_tables);
+    my $sth = $dbh->prepare("show create table " . $dbh->quote_identifier($table_name));
+    $sth->execute;
+    my $table = $sth->fetchrow_hashref;
+    $create .= ($table->{'create table'} || $table->{'create view'}) . ";\n\n";
+  }
 
-    SQL::Translator::Parser::MySQL::parse( $tr, $create );
+  SQL::Translator::Parser::MySQL::parse($tr, $create);
 
-    return 1;
+  return 1;
 }
 
 1;
