@@ -3,9 +3,9 @@ package SQL::Translator::Producer;
 use strict;
 use warnings;
 use Scalar::Util ();
-our $VERSION = '1.64';
+our $VERSION = '1.65';
 
-sub produce { "" }
+sub produce {""}
 
 # Do not rely on this if you are not bundled with SQL::Translator.
 # -- rjbs, 2008-09-30
@@ -19,38 +19,39 @@ sub _apply_default_value {
   my $default = $field->default_value;
   return if !defined $default;
 
-  if ($exceptions and ! ref $default) {
+  if ($exceptions and !ref $default) {
     for (my $i = 0; $i < @$exceptions; $i += 2) {
       my ($pat, $val) = @$exceptions[ $i, $i + 1 ];
       if (ref $pat and $default =~ $pat) {
-          $default = $val;
-          last;
+        $default = $val;
+        last;
       } elsif (lc $default eq lc $pat) {
-          $default = $val;
-          last
+        $default = $val;
+        last;
       }
     }
   }
 
   my $type = lc $field->data_type;
-  my $is_numeric_datatype = ($type =~ /^(?:(?:big|medium|small|tiny)?int(?:eger)?|decimal|double|float|num(?:ber|eric)?|real)$/);
+  my $is_numeric_datatype
+      = ($type =~ /^(?:(?:big|medium|small|tiny)?int(?:eger)?|decimal|double|float|num(?:ber|eric)?|real)$/);
 
   if (ref $default) {
-      $$field_ref .= " DEFAULT $$default";
-  } elsif ($is_numeric_datatype && Scalar::Util::looks_like_number ($default) ) {
-    # we need to check the data itself in addition to the datatype, for basic safety
-      $$field_ref .= " DEFAULT $default";
+    $$field_ref .= " DEFAULT $$default";
+  } elsif ($is_numeric_datatype && Scalar::Util::looks_like_number($default)) {
+# we need to check the data itself in addition to the datatype, for basic safety
+    $$field_ref .= " DEFAULT $default";
   } else {
-      $default = $self->_quote_string($default);
-      $$field_ref .= " DEFAULT $default";
+    $default = $self->_quote_string($default);
+    $$field_ref .= " DEFAULT $default";
   }
 
 }
 
 sub _quote_string {
-    my ($self, $string) = @_;
-    $string =~ s/'/''/g;
-    return qq{'$string'};
+  my ($self, $string) = @_;
+  $string =~ s/'/''/g;
+  return qq{'$string'};
 }
 
 1;
